package ope.components;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.util.Calendar;

import javax.swing.JComponent;

@SuppressWarnings("serial")
public class Clock extends JComponent {

	/**
	 * The current radius of the clock
	 */
	private int radius;

	/**
	 * Creates a new analog clock with preferred size 300x300.
	 */
	public Clock() {
		this.setPreferredSize(new Dimension(300, 300));
	}

	/* (non-Javadoc)
	 * @see javax.swing.JComponent#paintComponent(java.awt.Graphics)
	 */
	@Override
	public void paintComponent(Graphics graphics) {
		
		// The radius of the clock
		this.radius = Math.min(this.getWidth(), this.getHeight()) / 2;
		
		// Draw the clock background
		graphics.setColor(Color.ORANGE);
		graphics.fillOval(0, 0,	this.radius * 2, this.radius * 2);
		
		// Draw the clock face
		graphics.setColor(Color.BLACK);
		graphics.drawOval(0, 0, this.radius * 2, this.radius * 2);

		// Get the current time
		Calendar now = Calendar.getInstance();
		
		// Get the various time elements from the Calendar object.
		int hours = now.get(Calendar.HOUR);
		int minutes = now.get(Calendar.MINUTE);
		int seconds = now.get(Calendar.SECOND);
		
		// Print the current time
		//System.out.format("Redrawing clock at %02d:%02d:%02d\n", hours, minutes, seconds);
		
		// Draw the second hand with gray color
		double secondRadians = ClockMath.calculateSecondRadians(seconds);
		graphics.setColor(Color.GRAY);
		this.drawClockHand(graphics, secondRadians, this.radius);

		// Draw the rest of the hands with black color
		graphics.setColor(Color.BLACK);
		
		// Draw the minute hand
		double minuteRadians = ClockMath.calculateMinuteRadians(minutes, seconds);
		this.drawClockHand(graphics, minuteRadians, this.radius * 3/4);

		// Draw the hour hand
		double hourRadians = ClockMath.calculateHourRadians(hours, minutes, seconds);
		this.drawClockHand(graphics, hourRadians, this.radius / 2);
		
	}

	/**
	 * Draws a line at the center of the clock, pointing at to the
	 * given direction (in radians) and has a length of the
	 * given distance.
	 * 
	 * @param graphics the graphics on which the drawing is done.
	 * @param angle the direction of the line in radians.
	 * @param distance the ending distance from the center.
	 */
	private void drawClockHand(Graphics graphics, double angle, int distance) {

		// Sine and cosine
		double sine = Math.sin(angle - Math.PI / 2);
		double cosine = Math.cos(angle - Math.PI / 2);

		// Start coordinates of the line
		int startX = this.radius;
		int startY = this.radius;

		// End coordinates of the line
		int endX = this.radius + (int) (distance * cosine);
		int endY = this.radius + (int) (distance * sine);
		
		// Draw the line
		graphics.drawLine(startX, startY, endX, endY);
	}

}
