package ope.components;

public class ClockMath {

	/**
	 * Calculates an angle (in radians) which tells the rotation of the second
	 * hand on an analog clock.
	 * 
	 * @param seconds
	 *            the number of seconds
	 * @return the rotation angle of the second hand (in radians)
	 */
	public static double calculateSecondRadians(int seconds) {
		return seconds / 60.0 * 2.0 * Math.PI;
	}

	/**
	 * Calculates an angle (in radians) which tells the rotation of the minute
	 * hand on an analog clock.
	 * 
	 * @param minutes
	 *            the number of minutes
	 * @param seconds
	 *            the number of seconds
	 * @return the rotation angle of the minute hand (in radians)
	 */
	public static double calculateMinuteRadians(int minutes, int seconds) {
		return (minutes + seconds / 60.0) / 60.0 * 2.0 * Math.PI;
	}

	/**
	 * Calculates an angle (in radians) which tells the rotation of the hour
	 * hand on an analog clock.
	 * 
	 * @param hours
	 *            the number of hours
	 * @param minutes
	 *            the number of minutes
	 * @param seconds
	 *            the number of seconds
	 * @return the rotation angle of the hour hand (in radians)
	 */
	public static double calculateHourRadians(int hours, int minutes,
			int seconds) {
		return (hours + (minutes + seconds / 60.0) / 60.0) / 12.0 * 2.0 * Math.PI;
	}

}
