package ope.components;

public class ClockUpdater implements Runnable {

	private final Clock clockToUpdate;
	
	/**
	 * Creates a new runnable clock updater for a given clock.
	 * Once run, the updater will request a repaint for the 
	 * clock on every second. 
	 * 
	 * @param clock the clock to be frequently updated
	 */
	public ClockUpdater(Clock clock) {
		this.clockToUpdate = clock;
	}
	
	@Override
	public void run() {
		
		try {
			while (true) {
				
				// Repaint the clock
				this.clockToUpdate.repaint();
				
				// Sleep for a while
				Thread.sleep(1000);
				
			}
		} catch (InterruptedException e) {

			// Thread interrupted!
			// Let the method return.
		}
		
	}
	
}
